@@ -32,11 +32,13 @@ import socket
 import random
 import string
 import cl_utils
-import imp
 ##############################################################################
 
 _expand_lang = gettext._expand_lang
 
+def exit(codeExit):
+    """Метод выхода из программы"""
+    sys.exit(codeExit)
 
 def __findFileMO(domain, localedir=None, languages=None, all=0):
     # Модифицинрованный метод модуля gettext ищет файл перевода
